diff -u -r -N sugar-0.88.1.original/extensions/cpsection/accessibility/model.py sugar-0.88.1/extensions/cpsection/accessibility/model.py
--- sugar-0.88.1.original/extensions/cpsection/accessibility/model.py	2010-07-07 11:39:07.592689000 -0300
+++ sugar-0.88.1/extensions/cpsection/accessibility/model.py	2010-07-08 16:50:20.098168299 -0300
@@ -23,7 +23,7 @@
 screen = accessibility.Screen()
 mouse = accessibility.Mouse()
 
-KEYWORDS = ['mouse_keys', 'sticky_keys', 'bounce_keys', 'contrast', 'white_mouse', 'accel_mouse']
+KEYWORDS = ['mouse_keys', 'sticky_keys', 'bounce_keys', 'contrast', 'white_mouse', 'accel_mouse', 'capital_letters']
 
 def get_mouse_keys():
     return keyboard.get_mouse_keys()
@@ -61,6 +61,15 @@
 def print_contrast():
     print str(get_contrast())
 
+def get_capital_letters():
+    return screen.get_capital_letters()
+
+def set_capital_letters(activar):
+    screen.set_capital_letters(activar)
+
+def print_capital_letters():
+    print str(get_capital_letters())
+
 def get_white_mouse():
     return mouse.get_white_mouse()
 
diff -u -r -N sugar-0.88.1.original/extensions/cpsection/accessibility/view.py sugar-0.88.1/extensions/cpsection/accessibility/view.py
--- sugar-0.88.1.original/extensions/cpsection/accessibility/view.py	2010-07-07 13:32:25.853041000 -0300
+++ sugar-0.88.1/extensions/cpsection/accessibility/view.py	2010-07-09 12:17:08.900311273 -0300
@@ -96,6 +96,7 @@
         self.box_pm_screen.set_spacing(style.DEFAULT_SPACING)
 
         self._view_contrast()
+        self._view_letters()
 
         self._vbox_section.pack_start(self.box_pm_screen, expand=False)
         self.box_pm_screen.show()
@@ -140,6 +141,14 @@
         self._zone_alert.props.msg = self.restart_msg
         self._zone_alert.show()
 
+    def _set_capital_letters(self, widget):
+        state = widget.get_active()
+        self._model.set_capital_letters(state)
+        self.restart_alerts.append('zone')
+        self.needs_restart = True
+        self._zone_alert.props.msg = self.restart_msg
+        self._zone_alert.show()
+
     def _set_white_mouse(self, widget):
         state = widget.get_active()
         self._model.set_white_mouse(state)
@@ -159,6 +168,9 @@
         self._model.set_contrast(self.init_state_contrast)
         self.btn_contrast.set_active(self.init_state_contrast)
 
+        self._model.set_capital_letters(self.init_state_capital_letters)
+        self.btn_capital_letters.set_active(self.init_state_capital_letters)
+
         self._model.set_white_mouse(self.init_state_white_mouse)
         self.btn_white_mouse.set_active(self.init_state_white_mouse)
         
@@ -225,6 +237,24 @@
         self.box_pm_screen.pack_start(lbl_contrast, True, True, 2)
         lbl_contrast.show()
 
+    def _view_letters(self):
+        self.btn_capital_letters = gtk.CheckButton(_('Capital letters'))
+        self._capital_letters_pm_change_handler = self.btn_capital_letters.connect("toggled", self._set_capital_letters)
+        self.init_state_capital_letters = self._model.get_capital_letters()
+        if self.init_state_capital_letters:
+    	    self.btn_capital_letters.handler_block(self._capital_letters_pm_change_handler)
+            self.btn_capital_letters.set_active(True)
+            self.btn_capital_letters.handler_unblock(self._capital_letters_pm_change_handler)
+        else:
+            self.btn_capital_letters.set_active(False)
+        self.box_pm_screen.pack_start(self.btn_capital_letters, True, True, 2)
+        self.btn_capital_letters.show()
+
+        lbl_capital_letters = gtk.Label(_('Shows capital letters in the user interface.'))
+        lbl_capital_letters.set_alignment(0, 0)
+        self.box_pm_screen.pack_start(lbl_capital_letters, True, True, 2)
+        lbl_capital_letters.show()
+
     def _view_white_mouse(self):
         self.btn_white_mouse = gtk.CheckButton(_('White Mouse'))
         self._white_mouse_pm_change_handler = self.btn_white_mouse.connect("toggled", self._set_white_mouse)
@@ -265,4 +295,7 @@
         desc_accel_mouse = gtk.Label(_('Controller acceleration mouse.'))
         desc_accel_mouse.set_alignment(0, 0)
         self.box_pm_mouse.pack_start(desc_accel_mouse, True, True, 2)
-        desc_accel_mouse.show()
\ No hay ningún carácter de nueva línea al final del fichero
+        desc_accel_mouse.show()
+
+    def setup(self):
+        pass
\ No hay ningún carácter de nueva línea al final del fichero
diff -u -r -N sugar-0.88.1.original/src/jarabe/model/accessibility.py sugar-0.88.1/src/jarabe/model/accessibility.py
--- sugar-0.88.1.original/src/jarabe/model/accessibility.py	2010-07-08 14:26:37.651094000 -0300
+++ sugar-0.88.1/src/jarabe/model/accessibility.py	2010-07-09 09:44:07.768479236 -0300
@@ -68,10 +68,12 @@
 
 class Screen:
 
-    DEFAULT_THEME="sugar"
-    DEFAULT_FONT_SIZE=7
-    CONTRAST_THEME="sugar-contrast"
-    CONTRAST_FONT_SIZE=9.5
+    DEFAULT_THEME = "sugar"
+    DEFAULT_FONT_SIZE = 7
+    DEFAULT_FONT_FACE = "Sans Serif"
+    CONTRAST_THEME = "sugar-contrast"
+    CONTRAST_FONT_SIZE = 9.5
+    CAPITAL_LETTERS_FONT_FACE = "Oracle"
 
     def get_contrast(self):
         client = gconf.client_get_default()
@@ -87,6 +89,19 @@
             client.set_string("/desktop/sugar/interface/gtk_theme", self.DEFAULT_THEME)
             client.set_float('/desktop/sugar/font/default_size', self.DEFAULT_FONT_SIZE)
 
+    def get_capital_letters(self):
+        client = gconf.client_get_default()
+        value = client.get_string("/desktop/sugar/font/default_face")
+        return value==self.CAPITAL_LETTERS_FONT_FACE
+
+    def set_capital_letters(self, activar):
+        client = gconf.client_get_default()
+        if (activar):
+            client.set_string('/desktop/sugar/font/default_face', self.CAPITAL_LETTERS_FONT_FACE)
+        else:
+            client.set_string('/desktop/sugar/font/default_face', self.DEFAULT_FONT_FACE)
+
+
 class Mouse:
 
     WHITE_CURSOR_THEME="FlatbedCursors.White.Huge"
